metadata(version="0.5.1")

require("base64")
require("binascii")
require("quopri")
require("re")
require("string")

package("email")
